import QtQuick 2.5
import Fly.Components 1.0

FlyPage {
    id: settingsPage

    property var reloadMaster
    property string settingsGroup: ""

    readonly property bool horizontalAlignment: centerRect.width > centerRect.height

    titleImage.imagePath: "image://ThemeImageProvider/view-media-equalizer"
    titleImage.imageColorEnabled: false
    titleImage.imageShadow: false

    okFunction: function() { clock.saveSettings(); reloadMaster() }

    Rectangle {
        id: bottomLeftItem
        x: centerRect.x; y: centerRect.y + (horizontalAlignment ? 0 : centerRect.height / 2 + 10 * dpiRatio)
        width: horizontalAlignment ? centerRect.width / 2 - 10 * dpiRatio : centerRect.width
        height: horizontalAlignment ? centerRect.height : centerRect.height / 2 - 10 * dpiRatio
        color: styles.colors.white

        FlySettingsListView {
            id: listView

            property var categoryDisplay: FlySettingsCategoryItemData { name: qsTr("Display components") }
            property var categoryColor: FlySettingsCategoryItemData { name: qsTr("Color settings") }

            anchors.fill: parent
            model: [
                categoryDisplay,
                clock.background,
                clock.border,
                clock.marks,
                clock.day,
                clock.numbers,
                clock.roman,
                categoryColor,
                clock.dark,
                clock.light,
                clock.red
            ]
        }
    }
    FlyInnerShadow { target: bottomLeftItem }


    Image {
        id: topRightItem
        x: centerRect.x + (settingsPage.horizontalAlignment ? centerRect.width / 2 : 0); y: centerRect.y
        width: settingsPage.horizontalAlignment ? centerRect.width / 2 : centerRect.width
        height: settingsPage.horizontalAlignment ? centerRect.height : centerRect.height / 2
        source: "qrc:/transparentTile.png"
        fillMode: Image.Tile
        horizontalAlignment: Image.AlignLeft; verticalAlignment: Image.AlignTop
    }
    FlyInnerShadow { target: topRightItem }
    Clock {
        id: clock
        anchors { fill: topRightItem; margins: 10 * dpiRatio }
    }
}
