import QtQuick 2.5
import Fly.Components 1.0

Item {
    id: digitalClock

    property var timeColor: FlySettingsColorItemData { name: qsTr("Time color") }
    property var dateColor: FlySettingsColorItemData { name: qsTr("Date color"); enabled: showDate.value }
    property var dateStyleColor: FlySettingsColorItemData { name: qsTr("Date style color"); enabled: showDate.value && showDateStyle.value }
    property var timeStyleColor: FlySettingsColorItemData { name: qsTr("Time style color"); enabled: showTimeStyle.value }
    property var showDateStyle: FlySettingsCheckBoxItemData { name: qsTr("Show date style"); enabled: showDate.value }
    property var showTimeStyle: FlySettingsCheckBoxItemData { name: qsTr("Show time style") }
    property var showDate: FlySettingsCheckBoxItemData { name: qsTr("Show date") }
    property var showSecs: FlySettingsCheckBoxItemData { name: qsTr("Show seconds") }
    property var showWeekday: FlySettingsCheckBoxItemData { name: qsTr("Show week day"); enabled: showDate.value }
    property var showMonthName: FlySettingsCheckBoxItemData { name: qsTr("Show month name"); enabled: showDate.value }
    property var showBoldHours: FlySettingsCheckBoxItemData { name: qsTr("Bold style on hours") }
    property var dateHeight: FlySettingsSpinBoxItemData { name: qsTr("Date height"); minValue: 10; maxValue: 81;
        description: value ? value + "%": ""; enabled: showDate.value }

    function showSettings() {
        root.addPage(Qt.resolvedUrl("Settings.qml"), { "title": qsTr("Settings"), "reloadMaster": loadSettings, "settingsGroup": digitalClock.settingsGroup })
    }

    function saveSettings() {
        settings.setString("timeColor", root.getColorString(timeColor.value), settingsGroup)
        settings.setString("dateColor", root.getColorString(dateColor.value), settingsGroup)
        settings.setString("dateStyleColor", root.getColorString(dateStyleColor.value), settingsGroup)
        settings.setString("timeStyleColor", root.getColorString(timeStyleColor.value), settingsGroup)
        settings.setBool("showDateStyle", showDateStyle.value, settingsGroup)
        settings.setBool("showTimeStyle", showTimeStyle.value, settingsGroup)
        settings.setBool("showDate", showDate.value, settingsGroup)
        settings.setBool("showSecs", showSecs.value, settingsGroup)
        settings.setBool("showWeekday", showWeekday.value, settingsGroup)
        settings.setBool("showMonthName", showMonthName.value, settingsGroup)
        settings.setBool("showBoldHours", showBoldHours.value, settingsGroup)
        settings.setInt("dateHeight", dateHeight.value, settingsGroup)
    }

    function loadSettings() {
        timeColor.value = settings.getString("timeColor", settingsGroup, "white")
        dateColor.value = settings.getString("dateColor", settingsGroup, "white")
        dateStyleColor.value = settings.getString("dateStyleColor", settingsGroup, "black")
        timeStyleColor.value = settings.getString("timeStyleColor", settingsGroup, "black")
        showDate.value = settings.getBool("showDate", settingsGroup, true)
        showDateStyle.value = settings.getBool("showDateStyle", settingsGroup, true)
        showTimeStyle.value = settings.getBool("showTimeStyle", settingsGroup, true)
        showSecs.value = settings.getBool("showSecs", settingsGroup, false)
        showWeekday.value = settings.getBool("showWeekday", settingsGroup, true)
        showMonthName.value = settings.getBool("showMonthName", settingsGroup, true)
        showBoldHours.value = settings.getBool("showBoldHours", settingsGroup, false)
        dateHeight.value = settings.getInt("dateHeight", settingsGroup, 30)
    }

    property string timeFormat: ":mm" + (showSecs.value ? ":ss" : "")
    property string dateFormat: (showWeekday.value ? "dddd, " : "") + "dd" + (showMonthName.value ? " MMMM, " : ".MM.") + "yyyy"

    Text {
        id: timeLabel
        width: parent.width; height: parent.height - (dateLabel.visible ? dateLabel.height + 5 : 0)
        font.pixelSize: height; minimumPixelSize: 10
        fontSizeMode: Text.HorizontalFit
        text: (showBoldHours.value ? "<b>" + Qt.formatTime(root.currentDate, "hh") + "</b>" : Qt.formatTime(root.currentDate, "hh"))
              + Qt.formatTime(root.currentDate, timeFormat)
        textFormat: showBoldHours.value ? Text.StyledText : Text.PlainText
        color: timeColor.value
        styleColor: timeStyleColor.value; style: showTimeStyle.value ? Text.Raised : Text.Normal
        horizontalAlignment: Text.AlignHCenter; verticalAlignment: Text.AlignVCenter
        //renderType: Text.NativeRendering
    }

    Text {
        id: dateLabel
        anchors.bottom: parent.bottom
        width: parent.width; height: parent.height * dateHeight.value / 100
        font.pixelSize: parent.height * dateHeight.value / 100; minimumPixelSize: 5
        fontSizeMode: Text.HorizontalFit
        text: Qt.formatDate(root.currentDate, dateFormat)
        color: dateColor.value
        styleColor: dateStyleColor.value; style: showDateStyle.value ? Text.Raised : Text.Normal
        horizontalAlignment: Text.AlignHCenter; verticalAlignment: Text.AlignVCenter
        visible: showDate.value
        //renderType: Text.NativeRendering
    }

    MouseArea { anchors.fill: parent; onClicked: root.startDetachedProcess("fly-admin-date", []) }

    Component.onCompleted: loadSettings()
}
