import QtQuick 2.5
import Fly.Components 1.0

FlyPage {
    id: settingsPage

    property var reloadMaster
    property string settingsGroup: ""

    readonly property bool horizontalAlignment: centerRect.width > centerRect.height

    titleImage.imagePath: "image://ThemeImageProvider/view-media-equalizer"
    titleImage.imageColorEnabled: false
    titleImage.imageShadow: false

    okFunction: function() { clock.saveSettings(); reloadMaster() }

    Rectangle {
        id: bottomLeftItem
        x: centerRect.x; y: centerRect.y + (horizontalAlignment ? 0 : centerRect.height / 2 + 10 * dpiRatio)
        width: horizontalAlignment ? centerRect.width / 2 - 10 * dpiRatio: centerRect.width
        height: horizontalAlignment ? centerRect.height : centerRect.height / 2 - 10 * dpiRatio
        color: styles.colors.white

        FlySettingsListView {
            id: listView

            property var categoryTime: FlySettingsCategoryItemData { name: qsTr("Time settings") }
            property var categoryDate: FlySettingsCategoryItemData { name: qsTr("Date settings") }

            anchors.fill: parent
            model: [
                categoryTime,
                clock.showSecs,
                clock.showBoldHours,
                clock.timeColor,
                clock.showTimeStyle,
                clock.timeStyleColor,
                categoryDate,
                clock.showDate,
                clock.showWeekday,
                clock.showMonthName,
                clock.dateHeight,
                clock.dateColor,
                clock.showDateStyle,
                clock.dateStyleColor
            ]
        }
    }
    FlyInnerShadow { target: bottomLeftItem }


    Image {
        id: topRightItem
        x: centerRect.x + (settingsPage.horizontalAlignment ? centerRect.width / 2 : 0); y: centerRect.y
        width: settingsPage.horizontalAlignment ? centerRect.width / 2 : centerRect.width
        height: settingsPage.horizontalAlignment ? centerRect.height : centerRect.height / 2
        source: "qrc:/transparentTile.png"
        fillMode: Image.Tile
        horizontalAlignment: Image.AlignLeft; verticalAlignment: Image.AlignTop
    }
    FlyInnerShadow { target: topRightItem }
    DigitalClock {
        id: clock
        anchors { fill: topRightItem; margins: 10 * dpiRatio }
    }
}
