import QtQuick 2.5
import Fly.Components 1.0

Item {
    property string exec: ""
    property bool valid: false
    property bool isFolder: false

    property string customIcon: ""
    property string customText: ""

    function showSettings() {
        root.addPage(Qt.resolvedUrl("Settings.qml"),
                     {
                         "title": qsTr("Settings"),
                         "applySettings": applySettings,
                         "chooseShortcut": chooseShortcut,
                         "settingsGroup": settingsGroup,
                         "exec": exec,
                         "customIcon": customIcon,
                         "customText": customText,
                         "isFolder": isFolder
                     });
    }

    function chooseShortcut(callback) {
        root.showListViewPage(
                    {
                        "title": qsTr("Shortcut"),
                        "model": [qsTr("File"), qsTr("Folder")],
                        "cancelFunction": function() { // to split first time and launcher loading
                            if(exec === "") settings.setString("exec", "unknown", settingsGroup);
                        },
                        "okFunction": function(i) {
                            if(i === 0) {
                                var file = FlyFileDialog.chooseExistingFile();
                                if(file) callback(file, false);
                            } else {
                                var dir = FlyFileDialog.chooseExistingDirectory();
                                if(dir) callback(dir, true);
                            }
                        }
                    });
    }

    function applySettings(_exec, _isFolder, _customIcon, _customText) {
        _customIcon = _customIcon || "";
        _customText = _customText || "";

        settings.setString("exec", _exec, settingsGroup);
        settings.setBool("isFolder", _isFolder, settingsGroup);
        settings.setBool("valid", true, settingsGroup);
        settings.setString("customIcon", _customIcon, settingsGroup);
        settings.setString("customText", _customText, settingsGroup);

        exec = _exec;
        isFolder = _isFolder;
        customIcon = _customIcon;
        customText = _customText;
        valid = true;
    }

    function loadSettings() {
        exec = settings.getString("exec", settingsGroup, "");
        isFolder = settings.getBool("isFolder", settingsGroup, false);
        valid = settings.getBool("valid", settingsGroup, false);
        customIcon = settings.getString("customIcon", settingsGroup, "");
        customText = settings.getString("customText", settingsGroup, "");
    }

    Column {
        anchors.fill: parent

        FlyColoredImage {
            id: appButtonImage
            width: Math.min(parent.width, parent.height) * 0.5; height: width
            anchors { horizontalCenter: parent.horizontalCenter }
            pressed: appButtonMouseArea.pressed
            imagePath: !valid
                       ? "image://FileImageProvider/unknown"
                       : customIcon.length
                         ? customIcon
                         : "image://FileImageProvider/" + exec
            imageSourceSize: Qt.size(parent.width, parent.height)

            Image {
                id: shortcutImage
                anchors { bottom: parent.bottom; right: parent.right }
                source: "image://ThemeImageProvider/emblem-symbolic-link"
                sourceSize: Qt.size(parent.height * 0.25, parent.width * 0.25)
            }
        }

        FlyLabel {
            id: appName;
            width: parent.width - 14 * dpiRatio; height: parent.height - y - 10 * dpiRatio
            anchors.horizontalCenter: parent.horizontalCenter
            text: !valid
                  ? qsTr("<Shortcut>")
                  : customText.length
                    ? customText
                    : exec.split('/').pop()
            color: styles.colors.white
            style: Text.Raised; styleColor: styles.colors.black
            wrapMode: Text.WordWrap; elide: Text.ElideRight
            font.pixelSize: styles.label.smallest; minimumPixelSize: styles.label.tiny
            horizontalAlignment: Text.AlignHCenter
            antialiasing: true
        }
    }

    MouseArea {
        id: appButtonMouseArea
        anchors.fill: parent
        onClicked: {
            if(!valid || !exec.length) {
                chooseShortcut(applySettings);
            } else if(isFolder) {
                root.startDetachedProcess("fly-fm", [exec]);
            } else {
                Qt.openUrlExternally(exec);
            }
        }
    }

    Component.onCompleted: {
        loadSettings();

        if(exec === "" && !valid) // first time
            chooseShortcut(applySettings);
    }
}
